=======
Credits
=======

Development Lead
----------------

* zfit <zfit@physik.uzh.ch>


Authors
------------

| Jonas Eschle <jonas.eschle@cern.ch>
| Albert Puig <albert.puig@cern.ch>
| Rafael Silva Coutinho <rsilvaco@cern.ch>


Contributors
------------
| Chris Burr <christopher.burr@cern.ch>
| Matthieu Marinangeli <matthieu.marinangeli@cern.ch>
| Abhijit Mathad <amathad@cern.ch>
| Oliver Lantwin <oliver.lantwin@cern.ch>
